[FFmpeg-cvslog] r16062 - in trunk/libpostproc: postprocess.c postprocess.h

diego subversion
Thu Dec 11 21:06:17 CET 2008


Author: diego
Date: Thu Dec 11 21:06:16 2008
New Revision: 16062

Log:
Drop _t from typedef names for POSIX compatibility.


Modified:
   trunk/libpostproc/postprocess.c
   trunk/libpostproc/postprocess.h

Modified: trunk/libpostproc/postprocess.c
==============================================================================
--- trunk/libpostproc/postprocess.c	(original)
+++ trunk/libpostproc/postprocess.c	Thu Dec 11 21:06:16 2008
@@ -634,7 +634,7 @@ static av_always_inline void do_a_debloc
 // minor note: the HAVE_xyz is messed up after that line so do not use it.
 
 static inline void postProcess(const uint8_t src[], int srcStride, uint8_t dst[], int dstStride, int width, int height,
-        const QP_STORE_T QPs[], int QPStride, int isColor, pp_mode_t *vm, pp_context_t *vc)
+        const QP_STORE_T QPs[], int QPStride, int isColor, pp_mode *vm, pp_context *vc)
 {
     PPContext *c= (PPContext *)vc;
     PPMode *ppMode= (PPMode *)vm;
@@ -730,7 +730,7 @@ const char pp_help[] =
 "\n"
 ;
 
-pp_mode_t *pp_get_mode_by_name_and_quality(const char *name, int quality)
+pp_mode *pp_get_mode_by_name_and_quality(const char *name, int quality)
 {
     char temp[GET_MODE_BUFFER_SIZE];
     char *p= temp;
@@ -905,7 +905,7 @@ pp_mode_t *pp_get_mode_by_name_and_quali
     return ppMode;
 }
 
-void pp_free_mode(pp_mode_t *mode){
+void pp_free_mode(pp_mode *mode){
     av_free(mode);
 }
 
@@ -947,7 +947,7 @@ static const char * context_to_name(void
 
 static const AVClass av_codec_context_class = { "Postproc", context_to_name, NULL };
 
-pp_context_t *pp_get_context(int width, int height, int cpuCaps){
+pp_context *pp_get_context(int width, int height, int cpuCaps){
     PPContext *c= av_malloc(sizeof(PPContext));
     int stride= (width+15)&(~15);    //assumed / will realloc if needed
     int qpStride= (width+15)/16 + 2; //assumed / will realloc if needed
@@ -995,7 +995,7 @@ void  pp_postprocess(const uint8_t * src
                      uint8_t * dst[3], const int dstStride[3],
                      int width, int height,
                      const QP_STORE_T *QP_store,  int QPStride,
-                     pp_mode_t *vm,  void *vc, int pict_type)
+                     pp_mode *vm,  void *vc, int pict_type)
 {
     int mbWidth = (width+15)>>4;
     int mbHeight= (height+15)>>4;

Modified: trunk/libpostproc/postprocess.h
==============================================================================
--- trunk/libpostproc/postprocess.h	(original)
+++ trunk/libpostproc/postprocess.h	Thu Dec 11 21:06:16 2008
@@ -54,8 +54,8 @@ unsigned postproc_version(void);
 
 #include <inttypes.h>
 
-typedef void pp_context_t;
-typedef void pp_mode_t;
+typedef void pp_context;
+typedef void pp_mode;
 
 #if LIBPOSTPROC_VERSION_INT < (52<<16)
 extern const char *const pp_help; ///< a simple help text
@@ -67,19 +67,19 @@ void  pp_postprocess(const uint8_t * src
                      uint8_t * dst[3], const int dstStride[3],
                      int horizontalSize, int verticalSize,
                      const QP_STORE_T *QP_store,  int QP_stride,
-                     pp_mode_t *mode, pp_context_t *ppContext, int pict_type);
+                     pp_mode *mode, pp_context *ppContext, int pict_type);
 
 
 /**
  * returns a pp_mode_t or NULL if an error occurred
  * name is the string after "-pp" on the command line
  * quality is a number from 0 to PP_QUALITY_MAX
  */
-pp_mode_t *pp_get_mode_by_name_and_quality(const char *name, int quality);
-void pp_free_mode(pp_mode_t *mode);
+pp_mode *pp_get_mode_by_name_and_quality(const char *name, int quality);
+void pp_free_mode(pp_mode *mode);
 
-pp_context_t *pp_get_context(int width, int height, int flags);
-void pp_free_context(pp_context_t *ppContext);
+pp_context *pp_get_context(int width, int height, int flags);
+void pp_free_context(pp_context *ppContext);
 
 #define PP_CPU_CAPS_MMX   0x80000000
 #define PP_CPU_CAPS_MMX2  0x20000000
@@ -67,19 +67,19 @@ void  pp_postprocess(const uint8_t * src
 
 /**
- * returns a pp_mode_t or NULL if an error occurred
+ * returns a pp_mode or NULL if an error occurred
  * name is the string after "-pp" on the command line
  * quality is a number from 0 to PP_QUALITY_MAX




More information about the ffmpeg-cvslog mailing list